abacusai.code_bot — AbacusAI documentation

# abacusai.code_bot

## Classes

`CodeBot` | A bot option for CodeLLM

## Module Contents

class abacusai.code_bot.CodeBot(client, llmName=None, name=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A bot option for CodeLLM

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - llmName (str) – The name of the LLM.

    - name (str) – The name of the bot.

  llm_name = None
  name = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict